@@ -38,11 +38,18 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 
+#if TCP_WRAPPER
+#include <syslog.h>
+#include "log_tcp.h"
+int allow_severity=LOG_INFO;
+int deny_severity=LOG_WARNING;
+#endif
+
+extern char *progname;
 
 int debug_flag = 0;
 int dns_flag   = 0;
 
-
 static void Gperror(const char *str)
 {
     fprintf(stderr, "%s: GDBM Error Code #%d\n", str, gdbm_errno);
@@ -81,7 +88,38 @@ int gethostname(char *buf, int buflen)
 */
 static int is_valid_host(struct sockaddr_in *sin)
 {
+#if TCP_WRAPPER
+    extern int hosts_ctl(char *, char *, char *, char *);
+    int status;
+    static long oldaddr=0;	/* so we dont log multiple times */
+    static int oldstatus=-1;
+    char *h=NULL;
+
+#ifdef TRYRESOLVE
+    struct hostent *hp;
+
+    hp = gethostbyaddr((char *) &sin->sin_addr.s_addr,
+		       sizeof (sin->sin_addr.s_addr), AF_INET);
+
+    h = (hp && hp->h_name) ? hp->h_name : NULL;
+#endif
+
+    status = hosts_ctl(progname,
+		       h?h:FROM_UNKNOWN,
+		       inet_ntoa(sin->sin_addr),
+		       "");
+
+    if (sin->sin_addr.s_addr != oldaddr || status != oldstatus ) {
+	syslog(status?allow_severity:deny_severity,
+	       "%sconnect from %s\n",status?"":"refused ",
+	       h?h:inet_ntoa(sin->sin_addr));
+	oldaddr=sin->sin_addr.s_addr;
+	oldstatus=status;
+    }
+    return status;
+#else
     return 1;
+#endif
 }
 
 
@@ -1083,7 +1121,10 @@ ypresp_maplist *ypproc_maplist_2_svc(domainname *name,
 	if (dp == NULL)
 	{
 	    if (debug_flag)
-		perror("ypserv: opendir: .");
+	    {
+		fprintf(stderr, "%s: opendir: ", progname);
+		perror(".");
+	    }
 	    
 	    result.stat = YP_BADDB;
 	}
