@@ -2,7 +2,11 @@
 
 /* Stupid SunOS 4 doesn't have prototypes in the header files */
 
+/* Some includes just to make the compiler be quiet */
 #include <stdio.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+
 extern int fprintf(FILE *fp, const char *format, ...);
 extern int _flsbuf(unsigned char c, FILE *fp);
 extern int puts(const char *str);
@@ -13,6 +17,10 @@ extern int gethostname(char *buf, int bufsize);
 extern int atoi(const char *str);
 extern int perror(const char *str);
 
+extern int socket (int af, int type, int protocol);
+extern int bind (int s, struct sockaddr *name, int namelen);
+extern int chdir (const char *path);
+
 #endif
 
 
